chicagotransit
==============

A collection of wrappers to communicate with various chicago transit APIs and infosources.

Installation
------------

To install, use ``pip install chicagotransit``

Currently Supported
-------------------

- CTA Bustracker (Bustime)
- Divvy Bike Station Status
- Metrarail
- CTA TrainTracker

Future Expansion
----------------


- Pace Busses*

\*if some sort of public API can be found


Changelog
---------

**v0.4.0**

- Cleaned up some code
- Added support for CTA TrainTracker

**v0.3.0**

- Added some support for Metra Rail
- Cleaned up other code in order to meet PEP8


**v0.2.0**

- Added support for Divvy Bike Station Status


**v0.1.0**

- Added CTA Bustracker API (Bustime) support
